@@ -5,11 +5,11 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "iam-floyd", "0.54.0", __name__[0:-6], "iam-floyd@0.54.0.jsii.tgz"
+    "iam-floyd", "0.64.0", __name__[0:-6], "iam-floyd@0.64.0.jsii.tgz"
 )
 
 __all__ = [
